CodeTokenType enum
Enum for code token types
Values
- none → const CodeTokenType
- shortComment → const CodeTokenType
- longComment → const CodeTokenType
- string → const CodeTokenType
- number → const CodeTokenType
- constant → const CodeTokenType
- type → const CodeTokenType
- keyword → const CodeTokenType
- pragma → const CodeTokenType
- lowerCaseIdentifier → const CodeTokenType
- upperCaseIdentifier → const CodeTokenType
- minorCaseIdentifier → const CodeTokenType
- majorCaseIdentifier → const CodeTokenType
- identifier → const CodeTokenType
- operator → const CodeTokenType
- separator → const CodeTokenType
- delimiter → const CodeTokenType
- special → const CodeTokenType
- spacing → const CodeTokenType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CodeTokenType> - A constant List of the values in this enum, in order of their declaration.