Token class

Represents a token in the Pendown markup

Constructors

Token()

Properties

hashCode int
The hash code for this object.
no setterinherited
isEscaped bool
getter/setter pair
isSpace bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startsLine bool
getter/setter pair
text String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited