PendartParser class
Class for parsing Pendart markup and converting to Flutter widgets
Constructors
Properties
Methods
-
addTag(
String name, String definition) → void - Add a tag to the tag array
-
getCleanedText(
String text, int tabSpaceCount) → String - Get cleaned text with tabulations replaced with spaces
-
getColorizedText(
String text, String filePath, String fileExtension, String style) → String - Get text with colorized syntax highlighting
-
getPreprocessedText(
String text) → String - Get preprocessed text with code blocks highlighted
-
getTokenArray(
String text) → List< Token> - Get token array from Pendart text
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processText(
String text, BuildContext context, {bool isDarkMode = false, dynamic onCheckboxChanged(int, bool)?, bool enableCheckboxes = true}) → List< Widget> - Process Pendart text into a widget tree
-
removeTag(
String name) → void - Remove a tag from the tag array
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- indentationSpaceCount → const int
- tabulationSpaceCount → const int