TokenType enum
Token types for Pendart markup
Values
- text → const TokenType
- heading1 → const TokenType
- heading2 → const TokenType
- heading3 → const TokenType
- heading4 → const TokenType
- heading5 → const TokenType
- heading6 → const TokenType
- bold → const TokenType
- italic → const TokenType
- superscript → const TokenType
- subscript → const TokenType
- strikethrough → const TokenType
- underline → const TokenType
- codeBlock → const TokenType
- codeSpan → const TokenType
- horizontalRule → const TokenType
- pageBreak → const TokenType
- lineBreak → const TokenType
- checkbox → const TokenType
- image → const TokenType
- link → const TokenType
- space → const TokenType
- newline → const TokenType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited